@@ -1,5 +1,5 @@
 from starlette.types import Receive, Scope, Send
-from starlette.requests import HTTPConnection
+from starlette.requests import HTTPConnection, Request
 from starlette.responses import RedirectResponse
 from base64 import b64decode, b64encode
 from requests_oauthlib import OAuth2Session
@@ -51,7 +51,7 @@ def _get_cookie_data(oauth2_cookie_config, cookie_data):
 
 def _get_state_cookie(config, state):
     _cookie_content = {'state': state, 'type': 'state'}
-    data = b64encode(json.dump(_cookie_content).encode('utf-8'))
+    data = b64encode(json.dumps(_cookie_content).encode('utf-8'))
     data = _get_signer(config).sign(data)
     return data
 
@@ -84,7 +84,11 @@ async def process(config, scope: Scope, receive: Receive, send: Send) -> None:
                     pass
             else:
                 # no cookie > do oauth2 redirect
-                _client = OAuth2Session(oauth2_cookie_config['client_id'])
+                _request = Request(scope, receive)
+                _client = OAuth2Session(
+                    client_id=oauth2_cookie_config['client_id'],
+                    redirect_uri=str(_request.url)
+                )
                 _auth_url, state = _client.authorization_url(f"{oauth2_cookie_config['idp']}/authorize")
                 response = RedirectResponse(_auth_url, status_code=307)
                 response.set_cookie(
